ui

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfirmDeletion

func ConfirmDeletion(count int) (bool, error)

ConfirmDeletion prompts the user to confirm deletion using Bubble Tea

func PrintCurrentBranch

func PrintCurrentBranch(branch string)

PrintCurrentBranch prints the current branch info

func PrintDeletionProgress

func PrintDeletionProgress(branch string, success bool)

PrintDeletionProgress prints progress for each branch deletion

func PrintDeletionStart

func PrintDeletionStart()

PrintDeletionStart prints a message at the start of deletion

func PrintDryRunMessage

func PrintDryRunMessage()

PrintDryRunMessage prints a message for dry run mode

func PrintError

func PrintError(msg string)

PrintError prints an error message

func PrintFinalSummary

func PrintFinalSummary(deleted, failed int)

PrintFinalSummary prints the final summary after deletion

func PrintHeader

func PrintHeader()

PrintHeader prints the application header

func PrintInfo

func PrintInfo(msg string)

PrintInfo prints an info message

func PrintNoStaleBranches

func PrintNoStaleBranches(analysis *prune.BranchAnalysis)

PrintNoStaleBranches prints a message when no stale branches are found

func PrintProtectedBranches

func PrintProtectedBranches(branches []string)

PrintProtectedBranches prints the list of protected branches

func PrintStaleBranches

func PrintStaleBranches(branches []string)

PrintStaleBranches prints the list of stale branches

func PrintSuccess

func PrintSuccess(msg string)

PrintSuccess prints a success message

func PrintSummary

func PrintSummary(analysis *prune.BranchAnalysis)

PrintSummary prints a summary of the branch analysis

func PrintWarning

func PrintWarning(msg string)

PrintWarning prints a warning message

Types

This section is empty.

Jump to