Documentation
¶
Index ¶
- func ConfirmDeletion(count int) (bool, error)
- func PrintCurrentBranch(branch string)
- func PrintDeletionProgress(branch string, success bool)
- func PrintDeletionStart()
- func PrintDryRunMessage()
- func PrintError(msg string)
- func PrintFinalSummary(deleted, failed int)
- func PrintHeader()
- func PrintInfo(msg string)
- func PrintNoStaleBranches(analysis *prune.BranchAnalysis)
- func PrintProtectedBranches(branches []string)
- func PrintStaleBranches(branches []string)
- func PrintSuccess(msg string)
- func PrintSummary(analysis *prune.BranchAnalysis)
- func PrintWarning(msg string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfirmDeletion ¶
ConfirmDeletion prompts the user to confirm deletion using Bubble Tea
func PrintCurrentBranch ¶
func PrintCurrentBranch(branch string)
PrintCurrentBranch prints the current branch info
func PrintDeletionProgress ¶
PrintDeletionProgress prints progress for each branch deletion
func PrintDeletionStart ¶
func PrintDeletionStart()
PrintDeletionStart prints a message at the start of deletion
func PrintDryRunMessage ¶
func PrintDryRunMessage()
PrintDryRunMessage prints a message for dry run mode
func PrintFinalSummary ¶
func PrintFinalSummary(deleted, failed int)
PrintFinalSummary prints the final summary after deletion
func PrintNoStaleBranches ¶
func PrintNoStaleBranches(analysis *prune.BranchAnalysis)
PrintNoStaleBranches prints a message when no stale branches are found
func PrintProtectedBranches ¶
func PrintProtectedBranches(branches []string)
PrintProtectedBranches prints the list of protected branches
func PrintStaleBranches ¶
func PrintStaleBranches(branches []string)
PrintStaleBranches prints the list of stale branches
func PrintSummary ¶
func PrintSummary(analysis *prune.BranchAnalysis)
PrintSummary prints a summary of the branch analysis
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.